@@ -1,7 +1,7 @@
 /* provides a simple client program that reads ACPI status from the /proc filesystem
  *
- * Copyright (C) 2001  Grahame Bowland <grahame@angrygoats.net>
- *	    (C) 2008-2012  Michael Meskes  <meskes@debian.org>
+ * Copyright (C) 2001       Grahame Bowland <grahame@angrygoats.net>
+ *           (C) 2008-2013  Michael Meskes  <meskes@debian.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+ *  USA
  */
 
 #include <unistd.h>
@@ -26,6 +27,7 @@
 #include <getopt.h>
 #include <string.h>
 #include <errno.h>
+#include <time.h>
 
 #include "list.h"
 #include "acpi.h"
@@ -84,7 +86,7 @@ static struct field *parse_field(char *buf, char *given_attr)
 		break;
 	}
     } else {
-	strncpy(attr, given_attr, BUF_SIZE);
+	strncpy(attr, given_attr, BUF_SIZE-1);
     }
     strncpy(value, p, BUF_SIZE);
     if (attr[strlen(attr) - 1] == '\n')
@@ -247,7 +249,7 @@ static int get_unit_value(char *value)
     return n;
 }
 
-void print_battery_information(struct list *batteries, int show_empty_slots, int show_capacity)
+void print_battery_information(struct list *batteries, int show_empty_slots, int show_capacity, int show_remaining_time, int show_end_time, char *end_time_format)
 {
     struct list *battery = batteries;
     struct list *fields;
@@ -265,9 +267,12 @@ void print_battery_information(struct list *batteries, int show_empty_slots, int
 	int last_capacity_unit = -1;
 	int hours, minutes, seconds;
 	int percentage;
-	char *state = NULL, *poststr;
+	char *state = NULL, *poststr, *prestr;
 	int type_battery = TRUE;
 	char capacity_unit[4] = "mAh";
+	char stm[BUF_SIZE];
+	time_t end_time;
+	struct tm end_time_tm;
 
 	fields = battery->data;
 	while (fields) {
@@ -287,9 +292,9 @@ void print_battery_information(struct list *batteries, int show_empty_slots, int
 	    } else if (!strcasecmp(value->attr, "present rate")) {
 		present_rate = get_unit_value(value->value);
 	    } else if (!strcmp(value->attr, "current_now")) {
-		present_rate = get_unit_value(value->value) / 1000;
+		present_rate = abs(get_unit_value(value->value)) / 1000;
 	    } else if (!strcmp(value->attr, "power_now")) {
-		present_rate = get_unit_value(value->value) / 1000;
+		present_rate = abs(get_unit_value(value->value)) / 1000;
 	    } else if (!strcasecmp(value->attr, "last full capacity")) {
 		last_capacity = get_unit_value(value->value);
 		if (!state)
@@ -365,6 +370,7 @@ void print_battery_information(struct list *batteries, int show_empty_slots, int
 		    if (present_rate > MIN_PRESENT_RATE) {
 			seconds = 3600 * (last_capacity - remaining_capacity) / present_rate;
 			poststr = " until charged";
+			prestr = " fully charged at";
 		    } else {
 			poststr = "charging at zero rate - will never fully charge.";
 			seconds = -1;
@@ -373,6 +379,7 @@ void print_battery_information(struct list *batteries, int show_empty_slots, int
 		    if (present_rate > MIN_PRESENT_RATE) {
 			seconds = 3600 * remaining_capacity / present_rate;
 			poststr = " remaining";
+			prestr = " fully discharged at";
 		    } else {
 			poststr = "discharging at zero rate - will never fully discharge.";
 			seconds = -1;
@@ -383,11 +390,22 @@ void print_battery_information(struct list *batteries, int show_empty_slots, int
 		}
 
 		if (seconds > 0) {
-		    hours = seconds / 3600;
-		    seconds -= 3600 * hours;
-		    minutes = seconds / 60;
-		    seconds -= 60 * minutes;
-		    printf(", %02d:%02d:%02d%s", hours, minutes, seconds, poststr);
+		    if (show_remaining_time) {
+			hours = seconds / 3600;
+			seconds -= 3600 * hours;
+			minutes = seconds / 60;
+			seconds -= 60 * minutes;
+			printf(", %02d:%02d:%02d%s", hours, minutes, seconds, poststr);
+		    }
+
+		    end_time = time(NULL) + seconds;
+		    if (show_end_time && localtime_r(&end_time, &end_time_tm)) {
+			if (end_time_format && strftime(stm, sizeof(stm), end_time_format, &end_time_tm)) {
+			    printf(",%s %s", prestr, stm);
+			} else {
+			    printf(",%s %02i:%02d:%02d", prestr, end_time_tm.tm_hour, end_time_tm.tm_min, end_time_tm.tm_sec);
+			}
+		    }
 		} else if (poststr != NULL) {
 		    printf(", %s", poststr);
 		}
