@@ -1,8 +1,8 @@
 /* provides a simple client program that reads ACPI status from the /proc 
  * filesystem
  *
- * Copyright (C) 2001  Grahame Bowland <grahame@angrygoats.net>
- *                     Michael Meskes <meskes@debian.org>
+ * Copyright (C) 2001       Grahame Bowland <grahame@angrygoats.net>
+ *           (C) 2008-2013  Michael Meskes <meskes@debian.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+ *  USA
  */
 
 #ifndef _ACPI_H
@@ -60,7 +61,7 @@ struct list *find_devices(char *acpi_path, int device_nr, int proc_interface);
 
 void free_devices(struct list *devices);
 
-void print_battery_information(struct list *batteries, int show_empty_slots, int show_capacity);
+void print_battery_information(struct list *batteries, int show_empty_slots, int show_capacity, int show_remaining_time, int show_end_time, char *end_time_format);
 
 void print_ac_adapter_information(struct list *batteries, int show_empty_slots);
 
