@@ -1,8 +1,8 @@
 /* provides a simple client program that reads ACPI status from the /proc 
  * filesystem
  *
- * Copyright (C) 2001  Grahame Bowland <grahame@angrygoats.net>
- * Copyright (C) 2008-2012  Michael Meskes <meskes@debian.org>
+ * Copyright (C) 2001       Grahame Bowland <grahame@angrygoats.net>
+ *           (C) 2008-2013  Michael Meskes <meskes@debian.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+ *  USA
  */
 
 #include <stdio.h>
@@ -32,12 +33,12 @@ struct device device[4] = {
 			{ COOLING_DEV, "fan", "thermal", "cooling_device" }
 			  };
 
-static void do_show_batteries(char *acpi_path, int show_empty_slots, int show_details, int proc_interface)
+static void do_show_batteries(char *acpi_path, int show_empty_slots, int show_details, int show_remaining_time, int show_end_time, char *end_time_format, int proc_interface)
 {
 	struct list *batteries;
 
 	batteries = find_devices(acpi_path, BATTERY, proc_interface);
-	print_battery_information(batteries, show_empty_slots, show_details);
+	print_battery_information(batteries, show_empty_slots, show_details, show_remaining_time, show_end_time, end_time_format);
 	free_devices(batteries);
 }
 
@@ -90,6 +91,9 @@ static int usage(char *argv[])
 "                             - battery capacity information\n"
 "                             - temperature trip points\n"
 "  -a, --ac-adapter         ac adapter information\n"
+"  -r, --remaining-time     show remaining time for (dis)charge\n"
+"  -e, --end-time           show end time for (dis)charge\n"
+"  -F, --format-time <str>  specify end-time format string\n"
 "  -t, --thermal            thermal information\n"
 "  -c, --cooling            cooling information\n"
 "  -V, --everything         show every device, overrides above options\n"
@@ -125,6 +129,9 @@ static struct option long_options[] = {
 	{ "everything", 0, 0, 'V' }, 
 	{ "proc", 0, 0, 'p' }, 
 	{ "details", 0, 0, 'i' }, 
+	{ "remaining-time", 0, 0, 'r' },
+	{ "end-time", 0, 0, 'e' },
+	{ "format-time", 1, 0, 'F' },
 	{ 0, 0, 0, 0 }, 
 };
 
@@ -136,17 +143,20 @@ int main(int argc, char *argv[])
 	int show_cooling = FALSE;
 	int show_empty_slots = FALSE;
 	int show_details = FALSE;
+	int show_remaining_time = 2;
+	int show_end_time = FALSE;
 	int proc_interface = FALSE;
 	int temperature_units = TEMP_CELSIUS;
 	int ch, option_index;
 	char *acpi_path = strdup(ACPI_PATH_SYS);
+	char *end_time_format = NULL;
 
 	if (!acpi_path) {
 		fprintf(stderr, "Out of memory in main()\n");
 		return -1;
 	}
 
-	while ((ch = getopt_long(argc, argv, "ipVbtashvfkcd:", long_options, &option_index)) != -1) {
+	while ((ch = getopt_long(argc, argv, "F:eripVbtashvfkcd:", long_options, &option_index)) != -1) {
 		switch (ch) {
 			case 'V':
 				show_batteries = show_ac_adapter = show_thermal = show_cooling = show_details = TRUE;
@@ -178,6 +188,22 @@ int main(int argc, char *argv[])
 			case 'k':
 				temperature_units = TEMP_KELVIN;
 				break;
+			case 'r':
+				show_remaining_time = TRUE;
+				break;
+			case 'e':
+				show_end_time = TRUE;
+				if (show_remaining_time==2) {
+					show_remaining_time = FALSE;
+				}
+				break;
+			case 'F':
+				end_time_format = strdup(optarg);
+				if (!end_time_format) {
+					fprintf(stderr, "Out of memory in main()\n");
+					return -1;
+					}
+				break;
 			case 'p':
 				proc_interface = TRUE;
 				free(acpi_path);
@@ -201,12 +227,22 @@ int main(int argc, char *argv[])
 		}
 	}
 
+
+	/* if neither -e nor -r was chosen, show remaining time, for backward compatibility */
+	if (show_remaining_time==2) {
+		show_remaining_time = TRUE;
+	}
+
+	if (end_time_format && !show_end_time) {
+		fprintf(stderr, "Warning: ignoring the time format since option -e is not specified");
+	}
+
 	/* if nothing was chosen, we show the battery information */
 	if (!show_batteries && !show_ac_adapter && !show_thermal && !show_cooling)
 		show_batteries = TRUE;
 
 	if (show_batteries) {
-		do_show_batteries(acpi_path, show_empty_slots, show_details, proc_interface);
+		do_show_batteries(acpi_path, show_empty_slots, show_details, show_remaining_time, show_end_time, end_time_format, proc_interface);
 	}
 	if (show_ac_adapter) {
 		do_show_ac_adapter(acpi_path, show_empty_slots, proc_interface);
